"""
Промежуточные инстансы, вот они по порядку слева направо:

1. `vkquivk.bot.Bot`
1. `vkquick.api.API`
"""
bot = None
api = None
